==> mfire-3.2.post1-py3-none-any.whl: mfire/text/wind/reducers/base_param_summary_builder.py <==
from abc import ABC, abstractmethod
from typing import Optional

import mfire.utils.mfxarray as xr
from mfire.composite.weather import WeatherComposite
from mfire.settings import TEXT_ALGO
from mfire.utils.date import Datetime
from mfire.utils.unit_converter import unit_conversion


class BaseParamSummaryBuilder(ABC):
    """BaseParamSummaryBuilder."""

    USED_DIMS: list = ["valid_time", "latitude", "longitude"]

    @abstractmethod
    def __init__(self, compo: WeatherComposite, data_arrays: dict):
        pass

    @staticmethod
    def _get_composite_units(compo: WeatherComposite, param_name: str) -> str:
        """Get the units of the param regarding the WeatherComposite."""
        return compo.units.get(
            param_name,
            TEXT_ALGO[compo.id][compo.algorithm]["params"][param_name]["default_units"],
        )

    def _count_data_points(self, data: xr.DataArray) -> int:
        """Count the number of points of a term grid data."""
        latitude_size: int = int(data[self.USED_DIMS[1]].size)
        longitude_size: int = int(data[self.USED_DIMS[2]].size)
        return latitude_size * longitude_size

    @staticmethod
    def _get_data_array(
        data_array: xr.DataArray,
        param_name: str,
        units: Optional[str] = None,
        nan_replace: Optional[float] = None,
        values_to_replace: Optional[list[tuple[float, float]]] = None,
    ) -> xr.DataArray:
        """Clean and convert the input data_array."""
        # Get the data
        data_array = data_array[param_name]

        # Replace nan if necessary
        if nan_replace is not None:
            data_array = data_array.fillna(nan_replace)

        # Replace values if necessary
        if values_to_replace is not None:
            for value_old, value_new in values_to_replace:
                data_array = data_array.where(data_array != value_old, value_new)

        # Convert the data if asked
        if units:
            data_array = unit_conversion(data_array, units)

        return data_array

    @abstractmethod
    def compute(self, reference_datetime: Datetime) -> dict:
        """Compute the summary."""

==> mfire-4.0.post1-py3-none-any.whl: mfire/text/wind/reducers/base_param_summary_builder.py <==
from abc import ABC, abstractmethod
from typing import Optional

import numpy as np

import mfire.utils.mfxarray as xr
from mfire.composite.component import SynthesisComposite
from mfire.settings import TEXT_ALGO
from mfire.utils.date import Datetime
from mfire.utils.unit_converter import unit_conversion


class BaseParamSummaryBuilder(ABC):
    """BaseParamSummaryBuilder."""

    USED_DIMS: list = ["valid_time", "latitude", "longitude"]

    @abstractmethod
    def __init__(self):
        pass

    @staticmethod
    def _get_composite_units(compo: SynthesisComposite, param_name: str) -> str:
        """Get the units of the param regarding the WeatherComposite."""
        return compo.units.get(
            param_name,
            TEXT_ALGO[compo.id][compo.algorithm]["params"][param_name]["default_units"],
        )

    @staticmethod
    def _process_param_data(
        dataset: xr.Dataset,
        data_var: str,
        units: Optional[str] = None,
        nan_replace: Optional[float] = None,
        values_to_replace: Optional[list[tuple[float, float]]] = None,
        decimals: Optional[int] = None,
    ) -> xr.Dataset:
        """Process the dataArray matching with the input data_var."""
        # Get the dataArray
        data_array = dataset[data_var]

        # Replace nan if necessary
        if nan_replace is not None:
            data_array = data_array.fillna(nan_replace)

        # Replace values if necessary
        if values_to_replace is not None:
            for value_old, value_new in values_to_replace:
                data_array = data_array.where(data_array != value_old, value_new)

        # Convert the data if asked
        if units is not None:
            data_array = unit_conversion(data_array, units)

        # Round if asked
        if decimals is not None:
            data_array = np.round(data_array, decimals=decimals)

        dataset[data_var] = data_array

        return dataset

    @staticmethod
    def _get_data_array(
        dataset: xr.Dataset,
        param_name: str,
        units: Optional[str] = None,
        nan_replace: Optional[float] = None,
        values_to_replace: Optional[list[tuple[float, float]]] = None,
    ) -> xr.DataArray:
        """Extract, clean and convert the dataArray matching the param_name var."""
        # Get the data
        data_array = dataset[param_name]

        # Replace nan if necessary
        if nan_replace is not None:
            data_array = data_array.fillna(nan_replace)

        # Replace values if necessary
        if values_to_replace is not None:
            for value_old, value_new in values_to_replace:
                data_array = data_array.where(data_array != value_old, value_new)

        # Convert the data if asked
        if units:
            data_array = unit_conversion(data_array, units)

        return data_array

    @abstractmethod
    def compute(self, reference_datetime: Datetime) -> dict:
        """Compute the summary."""
